@@ -40,11 +40,13 @@ typedef struct _xsltNumberData {
  * This data structure lists the various parameters needed to format numbers.
  */
 typedef struct _xsltFormatNumberInfo {
+    int	    integer_hash;	/* Number of '#' in integer part */
     int	    integer_digits;	/* Number of '0' in integer part */
     int	    frac_digits;	/* Number of '0' in fractional part */
     int	    frac_hash;		/* Number of '#' in fractional part */
     int	    group;		/* Number of chars per display 'group' */
     int     multiplier;		/* Scaling for percent or permille */
+    char    add_decimal;	/* Flag for whether decimal point appears in pattern */
     char    is_multiplier_set;	/* Flag to catch multiple occurences of percent/permille */
     char    is_negative_pattern;/* Flag for processing -ve prefix/suffix */
 } xsltFormatNumberInfo, *xsltFormatNumberInfoPtr;
