@@ -767,15 +767,20 @@ xsltProcessUserParamInternal(xsltTransformContextPtr ctxt,
 		href = ns->href;
 	    }
 	    xmlFree(prefix);
+	    prefix = NULL;
 	} else {
 	    href = NULL;
 	}
 	xmlFree(ncname);
+	ncname = NULL;
     } else {
 	href = NULL;
 	ncname = xmlStrdup(name);
     }
 
+    if (ncname == NULL)
+	return (-1);
+
     /*
      * Do the evaluation if @eval is non-zero.
      */
